/**************************************************************************************************
  TouchPanel.h
  Driver for the touch panel.
**************************************************************************************************/
#ifndef STMPE610_H
#define STMPE610_H


// Defines
#define CMDFIFOLEN 256  // Number of entries in the command fifo


// STMPE610 register addresses
#define CHIP_ID        0x00    //(16)
#define ID_VER         0x02    //(8)
#define SYS_CTRL1      0x03    //(8)
#define SYS_CTRL2      0x04    //(8)
#define SPI_CFG        0x08    //(8)
#define INT_CTRL       0x09    //(8)
#define INT_EN         0x0A    //(8)
#define INT_STA        0x0B    //(8)
#define GPIO_EN        0x0C    //(8)
#define GPIO_INT_STA   0x0D    //(8)
#define ADC_INT_EN     0x0E    //(8)
#define ADC_INT_STA    0x0F    //(8)
#define GPIO_SET_PIN   0x10    //(8)
#define GPIO_CLR_PIN   0x11    //(8)
#define GPIO_MP_STA    0x12    //(8)
#define GPIO_DIR       0x13    //(8)
#define GPIO_ED        0x14    //(8)
#define GPIO_RE        0x15    //(8)
#define GPIO_FE        0x16    //(8)
#define GPIO_AF        0x17    //(8)
#define ADC_CTRL1      0x20    //(8)
#define ADC_CTRL2      0x21    //(8)
#define ADC_CAPT       0x22    //(8)
#define ADC_DATA_CH0   0x30    //(16)
#define ADC_DATA_CH1   0x32    //(16)
#define ADC_DATA_CH2   0x34    //(16)     STMP811
#define ADC_DATA_CH3   0x36    //(16)     STMP811
#define ADC_DATA_CH4   0x38    //(16)
#define ADC_DATA_CH5   0x3A    //(16)
#define ADC_DATA_CH6   0x3C    //(16)
#define ADC_DATA_CH7   0x3E    //(16)
#define TSC_CTRL       0x40    //(8)
#define TSC_CFG        0x41    //(8)
#define WDW_TR_X       0x42    //(16)
#define WDW_TR_Y       0x44    //(16)
#define WDW_BL_X       0x46    //(16)
#define WDW_BL_Y       0x48    //(16)
#define FIFO_TH        0x4A    //(8)
#define FIFO_STA       0x4B    //(8)
#define FIFO_SIZE      0x4C    //(8)
#define TSC_DATA_X     0x4D    //(16)
#define TSC_DATA_Y     0x4F    //(16)
#define TSC_DATA_Z     0x51    //(8)
#define TSC_DATA_XYZ   0x52    //(32)
#define TSC_FRACTION_Z 0x56    //(8)
#define TSC_DATA       0x57    //(8)
#define TSC_I_DRIVE    0x58    //(8)
#define TSC_SHIELD     0x59    //(8)
#define TEMP_CTRL      0x60    //(8)      STMP811
#define TSC_DATA_1     0xD7


typedef struct {   // Elements saved on the command fifo
    char *Buff;    // Pointer to write/read buffer
    char CmdCode;  // Command: 1 - write, 2 = read
    char RegAd;    // Starting register address
    char Count;    // Number of registers to write/read using STMPE610 auto-increment
} TCommand;


// Function Prototypes
void ExtIntEnable(void);
void ExtIntEnable(void);

void PutFifo(char *Bfr, char Cmd, char Addr, char Cnt);
char GetFifo(void);
void STMPE_TimeoutCheck(unsigned TimeoutState);
void STMPE_SM(void);

// These functions are in <Project_Name>_driver.c
void Set_Index(unsigned short index);
void Write_Command(unsigned short cmd);
void Write_Data(unsigned int _data);





#endif